==> openliberty-src-20.0.0.1.zip: open-liberty-gm-20.0.0.1/dev/com.ibm.ws.transport.http/resources/OSGI-INF/welcome/nls/cs/messages.js <==
var messages = {
    WELCOME_SECTION: "Sekce Vítejte",
    WELCOME_SECTION_CONTENT: "Obsah sekce Vítejte",
    WELCOME_MESSAGE: "Vítejte ",
    WELCOME_IBM_OPEN_SOURCE: "Projekt IBM Open Source",
    WELCOME_LIGHTWEIGHT: "Odlehčený otevřený rámec pro sestavení a spuštění rychlých, efektivních cloudových mikroslužeb Java.",
    UFO: "UFO a paprsek",
    CLOUDS: "Cloudy",
    LOGOS_SECTION: "Sekce Loga",
    COMPATIBLE: "Open Liberty je kompatibilní implementace:",
    MICROPROFILE: "Logo MicroProfile",
    JAKARTA_EE: "Logo Jakarta EE",
    RESOURCES_SECTION: "Sekce Prostředky",
    RESOURCES: "Prostředky a nápověda",
    GITHUB: "Logo GitHub",
    TWITTER: "Logo Twitter",
    GITTER: "Logo Gitter",
    STACK_OVERFLOW: "Logo Přetečení zásobníku",
    GROUPS_IO: "Logo Groups.io",
    OL_SUPPORT: "Logo Open Liberty",
    DOCS: "Dokumentace", // Translate 'Documentation'
    COPYRIGHT: "Copyright",
    OPEN_LIBERTY_FOOTER: "Logo zápatí Liberty",
    COPYRIGHT_OPEN_LIBERTY: "Licencované materiály — Vlastnictví projektu Open Liberty, Copyright IBM Corp a další 1997, 2019. Projekt je distribuován za podmínek veřejné licence Eclipse Public License v1.", // COPYRIGHT_URL
    UPDATE_BANNER_SECTION: "Sekce Aktualizovat proužek",
    UPDATE_BANNER_SECTION_CONTENT: "Obsah sekce Aktualizovat proužek",
    HEADER_UPDATE_AVAILABLE: "Aktualizace je k dispozici: ",
    HEADER_DOWNLOAD_LINK: "Klepnutím stáhnete {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Aktualizace je k dispozici. Klepnutím stáhnete {0}", // Product name
    UPDATE_BANNER_CLOSE_BUTTON: "Proužek Zavřít aktualizaci",
    CONTEXT_ROOT_NOT_FOUND: "Kontextový kořenový adresář nebyl nalezen"
};

==> openliberty-src-20.0.0.12.zip: open-liberty-gm-20.0.0.12/dev/com.ibm.ws.transport.http/resources/OSGI-INF/welcome/nls/cs/messages.js <==
var messages = {
    WELCOME_SECTION: "Sekce Vítejte",
    WELCOME_SECTION_CONTENT: "Obsah sekce Vítejte",
    WELCOME_MESSAGE: "Vítejte v produktu ",
    WELCOME_IBM_OPEN_SOURCE: "Projekt IBM Open Source",
    WELCOME_LIGHTWEIGHT: "Odlehčený otevřený rámec pro sestavení a spuštění rychlých, efektivních cloudových mikroslužeb Java.",
    UFO: "UFO a paprsek",
    CLOUDS: "Cloudy",
    LOGOS_SECTION: "Sekce Loga",
    COMPATIBLE: "Open Liberty je kompatibilní implementace produktů:",
    MICROPROFILE: "Logo MicroProfile",
    JAKARTA_EE: "Logo Jakarta EE",
    RESOURCES_SECTION: "Sekce Prostředky",
    RESOURCES: "Prostředky a nápověda",
    GITHUB: "Logo GitHub",
    TWITTER: "Logo Twitter",
    GITTER: "Logo Gitter",
    STACK_OVERFLOW: "Logo Přetečení zásobníku",
    GROUPS_IO: "Logo Groups.io",
    OL_SUPPORT: "Logo Open Liberty",
    DOCS: "Dokumentace", // Translate 'Documentation'
    COPYRIGHT: "Copyright",
    OPEN_LIBERTY_FOOTER: "Logo zápatí Liberty",
    COPYRIGHT_OPEN_LIBERTY: "Licencované materiály — vlastnictví projektu Open Liberty. Copyright IBM Corp a další 1997, 2019. Projekt je distribuován za podmínek veřejné licence Eclipse Public License v1.", // COPYRIGHT_URL
    UPDATE_BANNER_SECTION: "Sekce Aktualizovat proužek",
    UPDATE_BANNER_SECTION_CONTENT: "Obsah sekce Aktualizovat proužek",
    HEADER_UPDATE_AVAILABLE: "Je k dispozici aktualizace: ",
    HEADER_DOWNLOAD_LINK: "Klepnutím stáhnete {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Je k dispozici aktualizace. Klepnutím stáhnete produkt {0}", // Product name
    UPDATE_BANNER_CLOSE_BUTTON: "Proužek Zavřít aktualizaci",
    CONTEXT_ROOT_NOT_FOUND: "Kontextový kořenový adresář nebyl nalezen"
};
